<?php
	class Persian_Wooommerce_Plugin {
		
		public $table_lang;
		public $table_cities;
		public $plugin_version;
		/**
		 * The current langauge
		 *
		 * @var string
		 */
		private $language;
		private $is_persian;
		
		public function __construct( $file ) {
			
			if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) )
				add_action( 'admin_notices', array($this,'enable_woocommerce_notify') ); 
				
			global $wpdb;
			$this->file = $file;
			$this->table_lang = $wpdb->prefix . "woocommerce_ir";
			$this->table_cities = $wpdb->prefix . "woocommerce_ir_cities";
			
			// Actions
			add_action( 'wp_ajax_persian_woocommerce_replace_texts', array($this,'replace_texts_callback') );
			add_action( 'wp_ajax_nopriv_persian_woocommerce_replace_texts', array($this,'replace_texts_callback') );
			add_action( 'plugins_loaded', array( $this, 'persian_woo_plugin_loaded') );
			add_action(	'admin_init', array( $this, 'redirect_to_woo_persian_about_page') );
			add_action( 'admin_menu', array( $this,'persian_woocommerce_create_menu') ); 
			
			// Filters
			add_filter( 'woocommerce_states', array( $this, 'iran_states') );
			add_filter( 'woocommerce_general_settings', array( $this, 'add_iran_cities_enable_settings') );
			add_filter( 'gettext',  array( $this, 'persian_woocommerce_gettext') );
			add_filter( 'gettext_with_context',  array( $this, 'persian_woocommerce_gettext') );
			add_filter( 'ngettext',  array( $this, 'persian_woocommerce_gettext') );
			add_filter( 'ngettext_with_context',  array( $this, 'persian_woocommerce_gettext') );
		}
		
		// Action functions
		public function enable_woocommerce_notify() {
			$message = sprintf("ووکامرس فارسی با موفقیت نصب و فعالسازی شده است . لطفا افزونه ووکامرس را از <a href='%s' target='_blank'>اینجا</a> فعال کنید.", admin_url('plugins.php') );
		        echo"<div class='notice update-nag'>$message</div>"; 
		}

		public function replace_texts_callback(){
			global $wpdb;
			$json['status'] = "NO";
			$json['rand'] = rand(100000000 , 999999999);
			$json['msg'] = "مشکلی هنگام افزودن حلقه رخ داد . لطفا مجددا تلاش کنید.";

			if(isset($_POST['text1'] , $_POST['text2'])){
				if(!empty($_POST['text1'])){
					$insert = $wpdb->insert($this->table_lang , array('text1' => $_POST['text1'] , 'text2' => $_POST['text2']));
					if($insert) {
						$json['status'] = "OK";
						$json['msg'] = sprintf('<div id="setting-error-persian_woocommerce_msg_%d" class="updated settings-error notice is-dismissible"><p><strong>حلقه (%s => %s) با موفقیت افزوده شد.</strong></p><button type="button" class="notice-dismiss"><span class="screen-reader-text">بستن این اعلان.</span></button></div>',$json['rand'],$_POST['text1'],$_POST['text2']);
						$json['code'] = sprintf('<tr><th scope="row" class="check-column"><input name="text_delete_id[]" value="%d" type="checkbox"></th><td class="text1 column-text1 has-row-actions column-primary" data-colname="حلقه‌ی اصلی">%s<button type="button" class="toggle-row"><span class="screen-reader-text">نمایش جزئیات بیشتر</span></button></td><td class="text2 column-text2" data-colname="حلقه‌ی جایگزین شده">%s</td></tr>', $wpdb->insert_id , $_POST['text1'] , $_POST['text2']);		
						$json['count'] = $wpdb->get_var("SELECT COUNT(*) FROM $this->table_lang") . " مورد";			
					}
					else
						$json['msg'] = sprintf('<div id="setting-error-persian_woocommerce_msg_%d" class="error settings-error notice is-dismissible"><p><strong>خطایی در زمان افزودن حلقه (%s => %s) به دیتابیس رخ داده است. لطفا مجددا تلاش کنید</strong></p><button type="button" class="notice-dismiss"><span class="screen-reader-text">بستن این اعلان.</span></button></div>',$json['rand'],$_POST['text1'],$_POST['text2']);
				}
				else
					$json['msg'] = sprintf('<div id="setting-error-persian_woocommerce_msg_%d" class="error settings-error notice is-dismissible"><p><strong>پر کردن فیلد کلمه‌ی مورد نظر اجباری می باشد.</strong></p><button type="button" class="notice-dismiss"><span class="screen-reader-text">بستن این اعلان.</span></button></div>',$json['rand']);
			}
			die(json_encode($json));
		}

		
		public function persian_woo_plugin_loaded() {
			
			$rel_path = dirname( plugin_basename( $this->file ) ) . '/languages/';
			$dir = dirname( plugin_dir_path( __FILE__ ));
			
			if ( $this->language == null ) {
				if(defined('WPLANG'))
					$this->language = get_option( 'WPLANG', WPLANG );
				else
					$this->language = get_option( 'WPLANG' );					
				$this->is_persian = ( $this->language == 'fa' || $this->language == 'fa_IR' );
			}
			
			if ( defined( 'ICL_LANGUAGE_CODE' ) ) {
				$this->is_persian = ( ICL_LANGUAGE_CODE == 'fa' );
			}
			
			$curLang = substr(get_bloginfo( 'language' ), 0, 2);
		
			if ( $this->is_persian || strtolower($curLang) == 'fa' ) {
				
				if ( is_admin() )
					load_textdomain( 'woocommerce', $dir . '/languages/admin-fa_IR.mo' );
		
				load_textdomain( 'woocommerce', $dir . '/languages/fa_IR.mo' );
			}
		
			$this->plugin_version = defined( 'PERSIAN_WOOCOMMERCE_VERSION') ? PERSIAN_WOOCOMMERCE_VERSION : '2';
			
			global $wpdb;
				
			if( !get_option("persian_woocommerce_rename_old_table")) {
				$old_table = $wpdb->prefix . 'Woo_Iran_Cities_By_HANNANStd';
				$old_table_exist = $wpdb->query("SHOW TABLES LIKE '$old_table'");
				if($old_table_exist == 1) {
					$rename = $wpdb->query("RENAME TABLE $old_table TO $this->table_cities");
					if($rename == 0) {
						update_option("persian_woocommerce_rename_old_table",$this->plugin_version);
						update_option( 'is_cities_installed', 'yes' );
					}
				}
			}
			
			if ( get_option( 'is_cities_installed') == 'yes' ) 
				return;

			if($wpdb->get_var("show tables like '{$this->table_cities}'") != $this->table_cities) {
				$sql_cities = "CREATE TABLE IF NOT EXISTS {$this->table_cities} (
					`id` mediumint(9) NOT NULL AUTO_INCREMENT,
					`state` tinytext NOT NULL,
					`city` tinytext NOT NULL,
					UNIQUE KEY id (id)
				) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;";
				require_once (ABSPATH . 'wp-admin/includes/upgrade.php');
				dbDelta($sql_cities);
				
				$iran_city_file = plugin_dir_path( __FILE__ ). '/iran-cities/data/iran_cities.csv';
				$lines =  file($iran_city_file);
				foreach( (array) $lines as $line_num => $line) {
					$row = explode(",",$line);
					$len = sizeof($row);
					for($i=0;$i<$len;$i++){
						$row[$i] = sanitize_text_field($row[$i]);
					}
					$iran_city_fields = array (
						'state' => $row[0],
						'city' => $row[1]
					);
					$wpdb->insert( $this->table_cities ,$iran_city_fields);
				}
			}
			update_option( 'is_cities_installed', 'yes' );
		}
		
		public function redirect_to_woo_persian_about_page() {
			if ( get_option( 'redirect_to_woo_persian_about_page' ) != 'yes') {
				update_option( 'redirect_to_woo_persian_about_page', 'yes' );
				$redirect_page = admin_url( 'admin.php?page=persian-woocommerce-about' );
				if (!headers_sent()) {
					wp_redirect($redirect_page);
				}
			}
		}
		
		public function persian_woocommerce_create_menu() {
			add_menu_page( 'ووکامرس فارسی', 'ووکامرس فارسی', 'manage_options' ,'persian-woocommerce', array($this,'persian_woocommerce_text') ,  plugins_url( 'assests/images/logo.png' , __FILE__ ) , '55.6' );
			add_submenu_page('persian-woocommerce', 'حلقه های ترجمه', 'حلقه های ترجمه', 'manage_options', 'persian-woocommerce', array($this,'persian_woocommerce_text'));
			add_submenu_page('persian-woocommerce', 'ابزار ها', 'ابزار ها', 'manage_options', 'persian-woocommerce-tools', array($this,'persian_woocommerce_tools'));
			add_submenu_page('persian-woocommerce', 'درباره ما', 'درباره ما', 'manage_options', 'persian-woocommerce-about', array($this,'persian_woocommerce_about'));
		}
		
		public function persian_woocommerce_text() {
			global $wpdb;
			include_once('persian-woocommerce-text.php');
		}
		
		public function persian_woocommerce_tools(){
			echo "<p>توجه : بزودی در این قسمت ابزار های کاربردی و کامل کننده ووکامرس قرار داده می شود! مطمئن باشید شگفت زده می شوید ...</p>";
		}
		
		public function persian_woocommerce_about() {
			include_once('persian-woocommerce-about.php');
		}
		
		// register hook functions
		static function persian_woo_install() {
			global $wpdb;
			update_option( 'is_cities_installed', 'no' );
			update_option( 'redirect_to_woo_persian_about_page', 'no' );
			$woocommerce_ir_sql = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}woocommerce_ir (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`text1` text CHARACTER SET utf8 COLLATE utf8_persian_ci NOT NULL,
				`text2` text CHARACTER SET utf8 COLLATE utf8_persian_ci,
				PRIMARY KEY (`id`)
			  ) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";
			require_once (ABSPATH . 'wp-admin/includes/upgrade.php');
			dbDelta($woocommerce_ir_sql);
		}
		
		static function uninstall_woo_iran_cities() {
			global $wpdb;
			update_option( 'is_cities_installed', 'no' );
			update_option( 'redirect_to_woo_persian_about_page', 'no' );
			$wpdb->query("DROP TABLE IF EXISTS $wpdb->table_cities");
		}
		
		// Filter functions
		public function iran_states( $states ) {

			$states['IR'] = array(
				'AL'  => __( 'البرز', 'woocommerce' ),
				'AR'  => __( 'اردبيل', 'woocommerce' ),
				'AE'  => __( 'آذربايجان شرقي', 'woocommerce' ),
				'AW'  => __( 'آذربايجان غربي', 'woocommerce' ),
				'BU'  => __( 'بوشهر', 'woocommerce' ),
				'CM'  => __( 'چهارمحال و بختياري', 'woocommerce' ),
				'FA'  => __( 'فارس', 'woocommerce' ),
				'GI'  => __( 'گيلان', 'woocommerce' ),
				'GO'  => __( 'گلستان', 'woocommerce' ),
				'HD'  => __( 'همدان', 'woocommerce' ),
				'HG'  => __( 'هرمزگان', 'woocommerce' ),
				'IL'  => __( 'ايلام', 'woocommerce' ),
				'IS'  => __( 'اصفهان', 'woocommerce' ),
				'KE'  => __( 'کرمان', 'woocommerce' ),
				'BK'  => __( 'کرمانشاه', 'woocommerce' ),
				'KS'  => __( 'خراسان شمالي', 'woocommerce' ),
				'KV'  => __( 'خراسان رضوي', 'woocommerce' ),
				'KJ'  => __( 'خراسان جنوبي', 'woocommerce' ),
				'KZ'  => __( 'خوزستان', 'woocommerce' ),
				'KB'  => __( 'کهگيلويه و بويراحمد', 'woocommerce' ),
				'KD'  => __( 'کردستان', 'woocommerce' ),
				'LO'  => __( 'لرستان', 'woocommerce' ),
				'MK'  => __( 'مرکزي', 'woocommerce' ),
				'MN'  => __( 'مازندران', 'woocommerce' ),
				'QZ'  => __( 'قزوين', 'woocommerce' ),
				'QM'  => __( 'قم', 'woocommerce' ),
				'SM'  => __( 'سمنان', 'woocommerce' ),
				'SB'  => __( 'سيستان و بلوچستان', 'woocommerce' ),
				'TE'  => __( 'تهران', 'woocommerce' ),
				'YA'  => __( 'يزد', 'woocommerce' ),
				'ZA'  => __( 'زنجان', 'woocommerce' ),
				
			);
			
			return $states;

		}
				
		public function add_iran_cities_enable_settings( $settings ) {
			$updated_settings = array();
			foreach ( $settings as $section ) {
				if ( isset( $section['id'] ) && 'general_options' == $section['id'] &&
				isset( $section['type'] ) && 'sectionend' == $section['type'] ) {
					$updated_settings[] = array(
						'name'     => __( 'فعالسازی شهرهای ایران' ),
						'id'       => 'woocommerce_iran_cities',
						'type'     => 'checkbox',
						'std'      => '1',  // WC < 2.0
						'default'  => '1',  // WC >= 2.0
						'desc'     => __( 'فعالسازی شهرهای ایران در صفحه تسویه حساب ( نسخه آزمایشی )' ),
					);						
				}
				$updated_settings[] = $section;
			}
			return $updated_settings;
		}
		
		public function persian_woocommerce_gettext( $text ) {
			static $replace, $keys;
			global $wpdb;
			if( !is_array($replace) ) {
				$replace = array();
				$query = $wpdb->get_results("SELECT * FROM {$this->table_lang};");
				if($wpdb->num_rows){
					foreach($query as $txt){
						$replace[$txt->text1] = $txt->text2;
					}
				}
				$keys = array_keys($replace);
			}

			return str_replace( $keys, $replace, $text );
		}
	}